@@ -31,6 +31,46 @@ def test_version_compare():
     assert not res
     res = utils.version_compare("3.7.9.4", "2.0.0", "*")
     assert res
+    res = utils.version_compare("2.10.0", "2.1.0", "2.1.5")
+    assert not res
+    res = utils.version_compare("2.10.0", "2.0.0", "2.9.10")
+    assert not res
+    res = utils.version_compare("2.0.0", None, "2.7.9", "2.0.0")
+    assert not res
+    res = utils.version_compare("2.7.9", "2.0.0", None, None, "2.7.9")
+    assert not res
+    res = utils.version_compare("1.0", "1.0", "3.0")
+    assert res
+    res = utils.version_compare("1.0", "1.0.0", "3.0")
+    assert res
+    res = utils.version_compare("2.0", "1.0", "3.0")
+    assert res
+    res = utils.version_compare("2.0.0", "1.0", "3.0")
+    assert res
+    res = utils.version_compare("3.0", "1.0", "3.0")
+    assert res
+    res = utils.version_compare("3.0.0", "1.0", "3.0")
+    assert res
+    res = utils.version_compare("4.0", "1.0", "3.0")
+    assert not res
+    res = utils.version_compare("2.9.10.5", "*", "*", None, "2.8.11")
+    assert not res
+    res = utils.version_compare("2.9.10.5", "2.0.0", "*", None, "2.9.10.5")
+    assert not res
+    res = utils.version_compare("2.9.10.3", "2.0.0", "*", None, "2.9.10.5")
+    assert res
+    res = utils.version_compare("2.9.10.4", "2.0.0", "*", None, "2.9.10.5")
+    assert res
+    res = utils.version_compare("2.9.10.3", "2.9.0", "2.9.10.4", None, None)
+    assert res
+    res = utils.version_compare("2.9.10.4", "2.9.0", "2.9.10.4", None, None)
+    assert res
+    res = utils.version_compare("2.9.10.3", None, "2.9.10.4")
+    assert res
+    res = utils.version_compare("2.9.10.4", None, "2.9.10.5")
+    assert res
+    res = utils.version_compare("2.9.10.4", None, "2.9.10.1")
+    assert not res
 
 
 def test_version_parts_compare():
