@@ -16,32 +16,32 @@ CPE_REGEX = re.compile(
 class VulnerabilitySource(metaclass=ABCMeta):
     @classmethod
     @abstractmethod
-    def download_all(local_store=True):
+    def download_all(cls, local_store=True):
         pass
 
     @classmethod
     @abstractmethod
-    def download_recent(local_store=True):
+    def download_recent(cls, local_store=True):
         pass
 
     @classmethod
     @abstractmethod
-    def bulk_search():
+    def bulk_search(cls):
         pass
 
     @classmethod
     @abstractmethod
-    def convert(data):
+    def convert(cls, data):
         pass
 
     @classmethod
     @abstractmethod
-    def store(data):
+    def store(cls, data):
         pass
 
     @classmethod
     @abstractmethod
-    def refresh():
+    def refresh(cls):
         pass
 
 
@@ -131,8 +131,10 @@ class VulnerabilityDetail(object):
         self,
         cpe_uri,
         package,
-        min_affected_version,
-        max_affected_version,
+        min_affected_version_including,
+        max_affected_version_including,
+        min_affected_version_excluding,
+        max_affected_version_excluding,
         severity,
         description,
         fixed_location,
@@ -143,11 +145,21 @@ class VulnerabilityDetail(object):
         parts = CPE_REGEX.match(cpe_uri)
         self.cpe_uri = cpe_uri
         self.package = package if package else parts.group("package")
-        self.min_affected_version = (
-            min_affected_version if min_affected_version else parts.group("version")
+        self.min_affected_version_including = (
+            min_affected_version_including
+            if min_affected_version_including
+            else parts.group("version")
         )
-        self.max_affected_version = (
-            max_affected_version if max_affected_version else parts.group("version")
+        self.max_affected_version_including = (
+            max_affected_version_including
+            if max_affected_version_including
+            else parts.group("version")
+        )
+        self.min_affected_version_excluding = (
+            min_affected_version_excluding if min_affected_version_excluding else None
+        )
+        self.max_affected_version_excluding = (
+            max_affected_version_excluding if max_affected_version_excluding else None
         )
         self.severity = Severity.from_str(severity)
         self.description = description
@@ -176,8 +188,10 @@ class VulnerabilityDetail(object):
         return VulnerabilityDetail(
             detail.get("cpe_uri"),
             detail.get("package"),
-            detail.get("min_affected_version"),
-            detail.get("max_affected_version"),
+            detail.get("min_affected_version_including"),
+            detail.get("max_affected_version_including"),
+            detail.get("min_affected_version_excluding"),
+            detail.get("max_affected_version_excluding"),
             detail.get("severity"),
             detail.get("description"),
             detail.get("fixed_location"),
@@ -195,18 +209,33 @@ class PackageIssue(object):
         self,
         affected_location,
         fixed_location,
-        min_affected_version=None,
-        max_affected_version=None,
+        min_affected_version_including=None,
+        max_affected_version_including=None,
+        min_affected_version_excluding=None,
+        max_affected_version_excluding=None,
     ):
         self.affected_location = VulnerabilityLocation.from_values(
-            affected_location, min_affected_version, max_affected_version
+            affected_location,
+            min_affected_version_including,
+            max_affected_version_including,
+            min_affected_version_excluding,
+            max_affected_version_excluding,
         )
-        # Extract the fixed version from fixed_location cpe uri
-        fixed_parts = CPE_REGEX.match(fixed_location) if fixed_location else None
-        if fixed_parts:
-            self.fixed_location = fixed_parts.group("version")
+        # If there is no fixed_location but there is max excluded version then consider that as the fix
+        if not fixed_location and max_affected_version_excluding:
+            self.fixed_location = max_affected_version_excluding
         else:
-            self.fixed_location = ""
+            if fixed_location and fixed_location.startswith("cpe"):
+                # Extract the fixed version from fixed_location cpe uri
+                fixed_parts = (
+                    CPE_REGEX.match(fixed_location) if fixed_location else None
+                )
+                if fixed_parts:
+                    self.fixed_location = fixed_parts.group("version")
+                else:
+                    self.fixed_location = ""
+            else:
+                self.fixed_location = fixed_location
 
     @staticmethod
     def from_dict(package_issue):
@@ -279,20 +308,40 @@ class VulnerabilityLocation(object):
         self.version = version
 
     @staticmethod
-    def from_values(cpe_uri, min_affected_version=None, max_affected_version=None):
+    def from_values(
+        cpe_uri,
+        min_affected_version_including=None,
+        max_affected_version_including=None,
+        min_affected_version_excluding=None,
+        max_affected_version_excluding=None,
+    ):
         if not cpe_uri:
             return None
         parts = CPE_REGEX.match(cpe_uri)
-        version = max_affected_version if max_affected_version else parts.group(3)
-        if min_affected_version and max_affected_version:
-            if min_affected_version == "*":
-                version = "<" + max_affected_version
-            elif max_affected_version == "*":
-                version = ">" + min_affected_version
-            elif min_affected_version == max_affected_version:
-                version = min_affected_version
+        version = (
+            max_affected_version_including
+            if max_affected_version_including
+            else parts.group(3)
+        )
+        version_left = ""
+        version_right = ""
+        if min_affected_version_excluding:
+            version_left = ">" + min_affected_version_excluding
+        if min_affected_version_including and min_affected_version_including != "*":
+            version_left = ">=" + min_affected_version_including
+        if max_affected_version_excluding:
+            version_right = "<" + max_affected_version_excluding
+        if max_affected_version_including and max_affected_version_including != "*":
+            version_right = "<=" + max_affected_version_including
+        if version_left and not version_right:
+            version = version_left
+        elif not version_left and version_right:
+            version = version_right
+        elif version_left and version_right:
+            if min_affected_version_including == max_affected_version_including:
+                version = max_affected_version_including
             else:
-                version = min_affected_version + "-" + max_affected_version
+                version = "{}-{}".format(version_left, version_right)
         if parts:
             return VulnerabilityLocation(
                 cpe_uri, parts.group("vendor"), parts.group("package"), version
