@@ -16,7 +16,17 @@ def build_index(index_list):
     idx = {}
     vendor_idx = {}
     for d in index_list:
-        ver_range_str = str(d.get("min_version")) + "-" + str(d.get("max_version"))
+        min_version = d.get(
+            "min_affected_version_excluding", d.get("min_affected_version_including")
+        )
+        max_version = d.get(
+            "max_affected_version_excluding", d.get("max_affected_version_including")
+        )
+        if not min_version:
+            min_version = "0"
+        if not max_version:
+            max_version = "*"
+        ver_range_str = str(min_version) + "-" + str(max_version)
         curr_list = idx.get(d["name"], [])
         curr_list.append(ver_range_str)
         idx[d["name"]] = curr_list
@@ -89,19 +99,33 @@ def _key_func(data, match_list):
     :return: True if there is a match False otherwise
     """
     package = ""
-    min_version = ""
-    max_version = ""
+    min_affected_version_including = ""
+    max_affected_version_including = ""
+    min_affected_version_excluding = None
+    max_affected_version_excluding = None
     cpe_uri = ""
     if isinstance(data, dict):
         cpe_uri = data["details"].get("cpe_uri")
         package = data["details"].get("package")
-        min_version = data["details"].get("min_affected_version", "0")
-        max_version = data["details"].get("max_affected_version", "*")
+        min_affected_version_including = data["details"].get(
+            "min_affected_version_including", "0"
+        )
+        min_affected_version_excluding = data["details"].get(
+            "min_affected_version_excluding", None
+        )
+        max_affected_version_including = data["details"].get(
+            "max_affected_version_including", "*"
+        )
+        max_affected_version_excluding = data["details"].get(
+            "max_affected_version_excluding", None
+        )
     else:
         cpe_uri = data.details.cpe_uri
         package = data.details.package
-        min_version = data.details.min_affected_version
-        max_version = data.details.max_affected_version
+        min_affected_version_including = data.details.min_affected_version_including
+        max_affected_version_including = data.details.max_affected_version_including
+        min_affected_version_excluding = data.details.min_affected_version_excluding
+        max_affected_version_excluding = data.details.max_affected_version_excluding
     vendor, _, _ = parse_cpe(cpe_uri)
     for match in match_list:
         name_ver = match.split("|")
@@ -109,7 +133,11 @@ def _key_func(data, match_list):
         if len(name_ver) == 2:
             # Check if we have a hit
             if name_ver[0] == package and version_compare(
-                name_ver[1], min_version, max_version
+                name_ver[1],
+                min_affected_version_including,
+                max_affected_version_including,
+                min_affected_version_excluding,
+                max_affected_version_excluding,
             ):
                 return True
         # Search by vendor, name and version
@@ -118,7 +146,13 @@ def _key_func(data, match_list):
             if (
                 name_ver[0] == vendor
                 and name_ver[1] == package
-                and version_compare(name_ver[2], min_version, max_version)
+                and version_compare(
+                    name_ver[2],
+                    min_affected_version_including,
+                    max_affected_version_including,
+                    min_affected_version_excluding,
+                    max_affected_version_excluding,
+                )
             ):
                 return True
     return False
@@ -127,7 +161,7 @@ def _key_func(data, match_list):
 def bulk_index_search(pkg_list):
     """
     """
-    ret_list = []
+    ret_list = set()
     for pkg in pkg_list:
         version_list = None
         vendor_idx_key = None
@@ -142,12 +176,14 @@ def bulk_index_search(pkg_list):
             vnum = pkg["version"]
             minver = vrange[0]
             maxver = vrange[1]
+            if not minver:
+                minver = "0"
             if version_compare(vnum, minver, maxver):
                 if vendor_idx_key:
-                    ret_list.append(vendor_idx_key + "|" + pkg["version"])
+                    ret_list.add(vendor_idx_key + "|" + pkg["version"])
                 else:
-                    ret_list.append(pkg["name"].lower() + "|" + pkg["version"])
-    return ret_list
+                    ret_list.add(pkg["name"].lower() + "|" + pkg["version"])
+    return list(ret_list)
 
 
 def index_search(name, version):
