@@ -15,9 +15,9 @@ import re
 import requests
 import ujson
 
-import vdb.lib.config as config
+from vdb.lib import config as config
 from vdb.lib.nvd import NvdSource
-from vdb.lib.utils import get_default_cve_data, fix_text
+from vdb.lib.utils import fix_text, get_default_cve_data
 
 logging.basicConfig(
     level=logging.INFO, format="%(levelname)s [%(asctime)s] %(message)s"
@@ -87,7 +87,7 @@ class GitHubSource(NvdSource):
     """GitHub CVE source
     """
 
-    def download_all(self):
+    def download_all(self, local_store=True):
         """Download all historic cve data
         """
         data_list = []
@@ -95,17 +95,18 @@ class GitHubSource(NvdSource):
         for y in range(0, int(config.gha_pages_count)):
             data, page_info = self.fetch(type=lastId)
             if data:
-                self.store(data)
+                if local_store:
+                    self.store(data)
                 data_list += data
             if page_info and page_info["hasNextPage"]:
                 lastId = page_info["endCursor"]
         return data_list
 
-    def download_recent(self):
+    def download_recent(self, local_store=True):
         """Method which downloads the recent CVE
         """
         data, page_info = self.fetch("recent")
-        if data:
+        if data and local_store:
             self.store(data)
         return data
 
@@ -154,6 +155,13 @@ class GitHubSource(NvdSource):
                 version_end_including = tmpA[len(tmpA) - 1].replace("<= ", "")
             elif tmpA[len(tmpA) - 1].startswith("< "):
                 version_end_excluding = tmpA[len(tmpA) - 1].replace("< ", "")
+        if (
+            not version_start_including
+            and not version_end_including
+            and not version_start_excluding
+            and not version_end_excluding
+        ):
+            version_start_including = version_str
         return (
             version_start_including,
             version_end_including,
@@ -203,16 +211,29 @@ class GitHubSource(NvdSource):
                     version_start_excluding,
                     version_end_excluding,
                 ) = self.get_version_range(version)
+                top_fix_version = p.get("firstPatchedVersion")
+                if not top_fix_version or not top_fix_version.get("identifier"):
+                    top_fix_version = {"identifier": ""}
+                fix_version = top_fix_version.get("identifier", {})
+                (
+                    fix_version_start_including,
+                    fix_version_end_including,
+                    fix_version_start_excluding,
+                    fix_version_end_excluding,
+                ) = self.get_version_range(fix_version)
+
                 severity = p["severity"]
                 score, severity, vectorString, attackComplexity = get_default_cve_data(
                     severity
                 )
+                exploitabilityScore = score
+                description = fix_text(cve["summary"])
                 tdata = config.CVE_TPL % dict(
                     cve_id=cve_id,
                     cwe_id="UNKNOWN",
                     assigner=assigner,
                     references=ujson.dumps(references),
-                    description=fix_text(cve["summary"]),
+                    description=description,
                     vectorString=vectorString,
                     vendor=vendor.lower(),
                     product=product.lower(),
@@ -221,15 +242,21 @@ class GitHubSource(NvdSource):
                     version_end_including=version_end_including,
                     version_start_excluding=version_start_excluding,
                     version_end_excluding=version_end_excluding,
+                    fix_version_start_including=fix_version_start_including,
+                    fix_version_end_including=fix_version_end_including,
+                    fix_version_start_excluding=fix_version_start_excluding,
+                    fix_version_end_excluding=fix_version_end_excluding,
                     severity=severity,
                     attackComplexity=attackComplexity,
                     score=score,
+                    exploitabilityScore=exploitabilityScore,
                     publishedDate=cve["publishedAt"],
                     lastModifiedDate=cve["updatedAt"],
                 )
                 try:
                     tdata_json = ujson.loads(tdata)
                     vuln = NvdSource.convert_vuln(tdata_json)
+                    vuln.description = description
                     ret_data.append(vuln)
                 except ujson.ValueError:
                     LOG.warning(tdata)
