@@ -166,7 +166,12 @@ class NpmSource(NvdSource):
             title = v.get("title", "")
             overview = v.get("overview", "")
             recommendation = v.get("recommendation", "")
-            description = "{}\n{}\n{}".format(title, overview, recommendation)
+            description = """# {}
+{}
+{}
+            """.format(
+                title, overview, recommendation
+            )
             # FIXME: This should include references
             references = (
                 [{"name": "npm advisory", "url": v.get("url")}] if v.get("url") else []
@@ -241,6 +246,6 @@ class NpmSource(NvdSource):
                     vuln.description = description
                     ret_data.append(vuln)
                 except Exception:
-                    print(description)
+                    pass
                 vr = vr + 1
         return ret_data
