@@ -3,10 +3,26 @@ import re
 from datetime import datetime
 from enum import Enum
 
+from semver import VersionInfo
+
 from vdb.lib import CPE_REGEX, PackageIssue, Severity, VulnerabilityOccurrence
 
 date_format_str = "%Y-%m-%dT%H:%M:%S"
 
+# semver base format
+BASEVERSION = re.compile(
+    r"""[vV]?
+        (?P<major>0|[1-9]\d*)
+        (\.
+        (?P<minor>0|[1-9]\d*)
+        (\.
+            (?P<patch>0|[1-9]\d*)
+        )?
+        )?
+    """,
+    re.VERBOSE,
+)
+
 
 class ClassNotFoundError(Exception):
     """docstring for ClassNotFoundError"""
@@ -46,7 +62,6 @@ Arguments: Dict object; the module which contains the class, the parsed object i
                     "Class '%s' not found in the given module!" % t
                 )
             except TypeError as te:
-                print(te)
                 raise TypeError(
                     "Make sure there is an constuctor that doesn't take any arguments (class: %s)"
                     % t
@@ -223,7 +238,49 @@ def normalise_version_str(version_num, normal_len):
     return version_num
 
 
-def version_compare(compare_ver, min_version, max_version):
+def semver_compatible(compare_ver, min_version, max_version):
+    """Method to check if all version numbers are semver compatible"""
+    return (
+        VersionInfo.isvalid(compare_ver)
+        and VersionInfo.isvalid(min_version)
+        and VersionInfo.isvalid(max_version)
+    )
+
+
+def convert_to_semver(version):
+    """
+    Convert an incomplete version string into a semver-compatible VersionInfo
+    object
+
+    * Tries to detect a "basic" version string (``major.minor.patch``).
+    * If not enough components can be found, missing components are
+        set to zero to obtain a valid semver version.
+
+    :param str version: the version string to convert
+    :return: a tuple with a :class:`VersionInfo` instance (or ``None``
+        if it's not a version) and the rest of the string which doesn't
+        belong to a basic version.
+    :rtype: tuple(:class:`VersionInfo` | None, str)
+    """
+    match = BASEVERSION.search(version)
+    if not match:
+        return (None, version)
+
+    ver = {
+        key: 0 if value is None else value for key, value in match.groupdict().items()
+    }
+    ver = VersionInfo(**ver)
+    rest = match.string[match.end() :]  # noqa:E203
+    return ver, rest
+
+
+def version_compare(
+    compare_ver,
+    min_version,
+    max_version,
+    min_affected_version_excluding=None,
+    max_affected_version_excluding=None,
+):
     """Function to check if the given version is between min and max version
 
     >>> utils.version_compare("3.0.0", "2.0.0", "2.7.9.4")
@@ -235,9 +292,47 @@ def version_compare(compare_ver, min_version, max_version):
     >>> utils.version_compare("4.0.0", "2.0.0", "*")
     True
     """
+    # Semver compatible and including versions provided
+    is_min_exclude = False
+    is_max_exclude = False
+    if (not min_version or min_version == "*") and min_affected_version_excluding:
+        min_version = min_affected_version_excluding
+        is_min_exclude = True
+    if (not max_version or max_version == "*") and max_affected_version_excluding:
+        max_version = max_affected_version_excluding
+        is_max_exclude = True
+    # Perform semver match once we have all the required versions
+    if compare_ver and min_version and max_version:
+        if semver_compatible(compare_ver, min_version, max_version):
+            min_value = VersionInfo.parse(compare_ver).compare(min_version)
+            max_value = VersionInfo.parse(compare_ver).compare(max_version)
+            min_check = min_value > 0 if is_min_exclude else min_value >= 0
+            max_check = max_value < 0 if is_max_exclude else max_value <= 0
+            return min_check and max_check
+
+        # We have an incompatible semver string. Try to convert to semver format
+        compare_semver, comprest = convert_to_semver(compare_ver)
+        min_semver, minrest = convert_to_semver(min_version)
+        max_semver, maxrest = convert_to_semver(max_version)
+        if (
+            compare_semver
+            and min_semver
+            and max_semver
+            and not comprest
+            and not minrest
+            and not maxrest
+        ):
+            min_value = compare_semver.compare(min_semver)
+            max_value = compare_semver.compare(max_semver)
+            # If we are confident about the versions post upgrade then return True
+            if min_value >= 0 and max_value <= 0:
+                return True
+
     compare_ver_build = None
     min_version_build = None
     max_version_build = None
+    if not min_version:
+        min_version = "0"
     # Extract any build string such as alpha or beta
     if "-" in compare_ver and compare_ver != "-":
         tmpA = compare_ver.split("-")
@@ -262,7 +357,9 @@ def version_compare(compare_ver, min_version, max_version):
         compare_ver = "0"
     # Simple case
     if not compare_ver_build and not min_version_build and not max_version_build:
-        if compare_ver == min_version or compare_ver == max_version:
+        if (compare_ver == min_version and not is_min_exclude) or (
+            compare_ver == max_version and not is_max_exclude
+        ):
             return True
     compare_ver_parts = str(compare_ver).split(".")
     min_version_parts = str(min_version).split(".")
@@ -284,9 +381,8 @@ def version_compare(compare_ver, min_version, max_version):
         and len(str(compare_ver_num)) == len(str(max_version_num))
     ):
         if compare_ver_num >= min_version_num and compare_ver_num <= max_version_num:
-            if (
-                compare_ver_build == min_version_build
-                or compare_ver_build == max_version_build
+            if (compare_ver_build == min_version_build and not is_min_exclude) or (
+                compare_ver_build == max_version_build and not is_max_exclude
             ):
                 return True
             if not compare_ver_build and (min_version_build or max_version_build):
@@ -346,7 +442,11 @@ def version_compare(compare_ver, min_version, max_version):
                 max_version_parts[i - 1]
             ):
                 return False
-
+    # This will remove false positives where the comparison version is an excluded version
+    if (is_min_exclude and compare_ver == min_version) or (
+        is_max_exclude and compare_ver == max_version
+    ):
+        return False
     return True
 
 
@@ -416,8 +516,10 @@ def convert_to_occurrence(datas):
                 package_issue=PackageIssue(
                     affected_location=cpe_uri,
                     fixed_location=vdetails.fixed_location,
-                    min_affected_version=vdetails.min_affected_version,
-                    max_affected_version=vdetails.max_affected_version,
+                    min_affected_version_including=vdetails.min_affected_version_including,
+                    max_affected_version_including=vdetails.max_affected_version_including,
+                    min_affected_version_excluding=vdetails.min_affected_version_excluding,
+                    max_affected_version_excluding=vdetails.max_affected_version_excluding,
                 ),
                 short_description=vobj["description"],
                 long_description=None,
